#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-reify-many
version:              0.1.9
visibility:           public
id:                   th-reify-many-0.1.9-FfrDSG3CoRT8cCN0ArDgUU
key:                  th-reify-many-0.1.9-FfrDSG3CoRT8cCN0ArDgUU
license:              BSD-3-Clause
maintainer:           Michael Sloan <mgsloan at gmail>
author:               Michael Sloan
stability:            Experimental
homepage:             http://github.com/mgsloan/th-reify-many
synopsis:             Recurseively reify template haskell datatype info
description:
    @th-reify-many@ provides functions for recursively reifying top
    level declarations.  The main intended use case is for enumerating
    the names of datatypes reachable from an initial datatype, and
    passing these names to some function which generates instances.

category:             Template Haskell
abi:                  923fb712ae2a6a80a02043ecb13b2f80
exposed:              True
exposed-modules:
    Language.Haskell.TH.ReifyMany
    Language.Haskell.TH.ReifyMany.Internal

import-dirs:          /usr/lib/ghc-8.10.5/site-local/th-reify-many-0.1.9
library-dirs:         /usr/lib/ghc-8.10.5/site-local/th-reify-many-0.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/th-reify-many-0.1.9
hs-libraries:         HSth-reify-many-0.1.9-FfrDSG3CoRT8cCN0ArDgUU
depends:
    base-4.14.2.0 containers-0.6.4.1 mtl-2.2.2
    safe-0.3.19-DlKvqLTtraZKItu5PR3KBM template-haskell-2.16.0.0
    th-expand-syns-0.4.8.0-LtRNSI7BRqeJXQujlt8rna

haddock-interfaces:
    /usr/share/doc/haskell-th-reify-many/html/th-reify-many.haddock

haddock-html:         /usr/share/doc/haskell-th-reify-many/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

